/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import java.time.ZonedDateTime;

import de.ozgcloud.eingang.common.formdata.FormMetaData;
import de.ozgcloud.eingang.common.formdata.IncomingFile;
import lombok.Builder;
import lombok.Getter;
import lombok.ToString;

@Builder
@Getter
@ToString
class XtaMessageMetaData implements FormMetaData {
	static final String SERVICE = "service";
	static final String MESSAGE_TYPE_ENTRY_NAME = "messageType";
	static final String MESSAGE_TYPE_LIST_VERSION = "messageTypeListVersion";
	static final String MESSAGE_ID_ENTRY_NAME = "messageId";
	static final String XTA_IDENTIFIER_ENTRY_NAME = "xtaIdentifier";

	// MsgIdentification.MessageId
	private XtaMessageId messageId;

	// DeliveryAttributes.origin
	private ZonedDateTime origin;
	// DeliveryAttributes.delivery
	private ZonedDateTime delivery;

	// Qualifier.MessageType.code
	private String messageType;
	// Qualifier.MessageType.listVersion
	private String messageTypeListVersion;
	// Qualifier.Service
	private String service;

	private String xtaIdentifier;

	private IncomingFile metaDataFile;

	@Override
	public String getEntry(String name) {
		switch (name) {
		case MESSAGE_TYPE_ENTRY_NAME:
			return getMessageType();
		case MESSAGE_TYPE_LIST_VERSION:
			return getMessageTypeListVersion();
		case MESSAGE_ID_ENTRY_NAME:
			return getMessageId().toString();
		case XTA_IDENTIFIER_ENTRY_NAME:
			return getXtaIdentifier();
		case SERVICE:
			return getService();

		default:
			return null;
		}
	}

}
