/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import java.math.BigInteger;
import java.net.URI;
import java.util.List;

import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.Resource;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Validated
@ToString
@Setter
@Getter
@Configuration
@ConfigurationProperties(prefix = XtaProperties.PROPERTIES_PREFIX)
class XtaProperties {
	static final String PROPERTIES_PREFIX = "ozgcloud.xta";

	private Server server;
	private BigInteger maxListElements;

	private KeyStore keyStore;
	private Actions actions;
	@NotEmpty
	private List<String> identifiers;
}

@Validated
@ToString
@Getter
@Setter
@Component
@ConfigurationProperties(prefix = Server.PROPERTIES_PREFIX)
class Server {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".server";

	@NotEmpty
	private String name;
	private String address;
	@NotEmpty
	private String protocol;
}

@Validated
@ToString
@Getter
@Setter
@Component
@ConfigurationProperties(prefix = KeyStore.PROPERTIES_PREFIX)
class KeyStore {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".keystore";

	@NotNull
	private Resource file;
	private String type = "PKCS12";
	@NotEmpty
	private char[] password;
}

@Validated
@ToString
@Setter
@Getter
@Configuration
@ConfigurationProperties(prefix = Actions.PROPERTIES_PREFIX)
class Actions {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".actions";

	@NotNull
	private URI statusList;
	@NotNull
	private URI fetchRequest;
	@NotNull
	private URI closeRequest;
}
